@@ -17,21 +17,23 @@ log_level = logging.INFO
 log_format = '%(asctime)s-%(levelname)s-%(module)s:%(lineno)d - %(message)s'
 log_filemode = 'a'
 
-logging_cfg = config.cfg.get('logging')
-if isinstance(logging_cfg, dict):
-    log_filemode = logging_cfg.get('filemode', log_filemode)
-    if isinstance(logging_cfg.get('format'), str):
-        log_format = logging_cfg.get('format').replace('&', '%')
+if config is not None:
+    if isinstance(config.cfg, dict):
+        logging_cfg = config.cfg.get('logging')
+        if isinstance(logging_cfg, dict):
+            log_filemode = logging_cfg.get('filemode', log_filemode)
+            if isinstance(logging_cfg.get('format'), str):
+                log_format = logging_cfg.get('format').replace('&', '%')
 
-    log_level = get_log_level(logging_cfg.get('level'), log_level)
-    sentry_sdk_dsn = logging_cfg.get('sentry_sdk_dsn')
-    if isinstance(sentry_sdk_dsn, str):
-        if sentry_sdk_dsn.lower() != 'none':
-            sentry_logging = LoggingIntegration(
-                level=logging.INFO,  # Capture info and above as breadcrumbs
-                event_level=logging.ERROR  # Send errors as events
-            )
-            sentry_sdk.init(dsn=sentry_sdk_dsn, integrations=[sentry_logging])
+            log_level = get_log_level(logging_cfg.get('level'), log_level)
+            sentry_sdk_dsn = logging_cfg.get('sentry_sdk_dsn')
+            if isinstance(sentry_sdk_dsn, str):
+                if sentry_sdk_dsn.lower() != 'none':
+                    sentry_logging = LoggingIntegration(
+                        level=logging.INFO,  # Capture info and above as breadcrumbs
+                        event_level=logging.ERROR  # Send errors as events
+                    )
+                    sentry_sdk.init(dsn=sentry_sdk_dsn, integrations=[sentry_logging])
 
 
 def init_logger(log_filename=None):
